==> open-cluster-management-apps-model-6.4.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/OverridesFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface OverridesFluent<A extends OverridesFluent<A>> extends Fluent<A>{
  public String getPackageAlias();
  public A withPackageAlias(String packageAlias);
  public Boolean hasPackageAlias();
  public String getPackageName();
  public A withPackageName(String packageName);
  public Boolean hasPackageName();
  public A addToPackageOverrides(Integer index,Map<String,Object> item);
  public A setToPackageOverrides(Integer index,Map<String,Object> item);
  public A addToPackageOverrides(Map<String,Object>... items);
  public A addAllToPackageOverrides(Collection<Map<String,Object>> items);
  public A removeFromPackageOverrides(Map<String,Object>... items);
  public A removeAllFromPackageOverrides(Collection<Map<String,Object>> items);
  public List<Map<String,Object>> getPackageOverrides();
  public Map<String,Object> getPackageOverride(Integer index);
  public Map<String,Object> getFirstPackageOverride();
  public Map<String,Object> getLastPackageOverride();
  public Map<String,Object> getMatchingPackageOverride(Predicate<Map<String,Object>> predicate);
  public Boolean hasMatchingPackageOverride(Predicate<Map<String,Object>> predicate);
  public <K,V>A withPackageOverrides(List<Map<String,Object>> packageOverrides);
  public A withPackageOverrides(Map<String,Object>... packageOverrides);
  public Boolean hasPackageOverrides();
  
}

==> open-cluster-management-apps-model-6.7.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/v1/OverridesFluent.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.v1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface OverridesFluent<A extends OverridesFluent<A>> extends Fluent<A>{
  public String getPackageAlias();
  public A withPackageAlias(String packageAlias);
  public Boolean hasPackageAlias();
  public String getPackageName();
  public A withPackageName(String packageName);
  public Boolean hasPackageName();
  public A addToPackageOverrides(int index,Map<String,Object> item);
  public A setToPackageOverrides(int index,Map<String,Object> item);
  public A addToPackageOverrides(Map<String,Object>... items);
  public A addAllToPackageOverrides(Collection<Map<String,Object>> items);
  public A removeFromPackageOverrides(Map<String,Object>... items);
  public A removeAllFromPackageOverrides(Collection<Map<String,Object>> items);
  public List<Map<String,Object>> getPackageOverrides();
  public Map<String,Object> getPackageOverride(int index);
  public Map<String,Object> getFirstPackageOverride();
  public Map<String,Object> getLastPackageOverride();
  public Map<String,Object> getMatchingPackageOverride(Predicate<Map<String,Object>> predicate);
  public Boolean hasMatchingPackageOverride(Predicate<Map<String,Object>> predicate);
  public <K,V>A withPackageOverrides(List<Map<String,Object>> packageOverrides);
  public A withPackageOverrides(Map<String,Object>... packageOverrides);
  public Boolean hasPackageOverrides();
  
}
